package com.newrelic.api.agent;

import java.util.Enumeration;

/**
 * Represents a web request.
 * 
 * The implementation of this interface does not need to be
 * servlet specific, but the api is based on the servlet spec.
 * 
 * @author sdaubin
 * 
 * @see NewRelic#setRequestAndResponse(Request, Response)
 * @see javax.servlet.http.HttpServletRequest
 */
public interface Request {
	/**
	 * Returns the part of this request's URL from the protocol name up to the 
	 * query string in the first line of the HTTP request.
	 * @return
	 */
	String getRequestURI();
	
	/**
	 * Returns the value of the specified request header as a String.
	 * @param name
	 * @return
	 */
	String getHeader(String name);
	
	/**
	 *  Returns the login of the user making this request, if the user has 
	 *  been authenticated, or null if the user has not been authenticated.
	 * @return
	 */
	String getRemoteUser();
	
	/**
	 * Returns an Enumeration of String objects containing the names of the 
	 * parameters contained in this request. If the request has no parameters, 
	 * the method returns an empty Enumeration.
	 * @return
	 */
	@SuppressWarnings("rawtypes")
	Enumeration getParameterNames();
	
	/**
	 * Returns an array of String objects containing all of the values the given 
	 * request parameter has, or null if the parameter does not exist.
	 * If the parameter has a single value, the array has a length of 1.
	 * @param name
	 * @return
	 */
	String[] getParameterValues(String name);

	/**
	 * Returns the value of the named attribute as an Object, or null if no attribute of the given name exists.
	 * @param name
	 * @return
	 */
	Object getAttribute(String name);
}
